@@ -15,7 +15,7 @@ use namespace::autoclean;
 
 requires qw/ log_stats /;
 
-our $VERSION = 'v0.4.2';
+our $VERSION = 'v0.5.0';
 
 
 sub statsd_client {
@@ -60,7 +60,9 @@ around log_stats => sub {
 
     }
 
-    $c->$next unless !!$config->{disable_stats_report};
+    my $disabled = $config->{disable_stats_report} // !$c->debug;
+
+    $c->$next unless $disabled;
 };
 
 
@@ -78,7 +80,7 @@ Catalyst::Plugin::Statsd - log Catalyst stats to statsd
 
 =head1 VERSION
 
-version v0.4.2
+version v0.5.0
 
 =head1 SYNOPSIS
 
@@ -122,6 +124,10 @@ Note that if you are modifying the C<log_stats> method or using
 another plugin that does this, then this may interfere with that if
 you disable the stats report.
 
+This defaults to
+
+    !$c->debug
+
 =head1 METHODS
 
 =head2 C<statsd_client>
@@ -159,6 +165,12 @@ L<Plack::Middleware::Statsd> also logs response times.
 
 These are metrics generated from L<Catalyst::Stats>.
 
+All non-word characters in the paths in an action are changed to dots,
+e.g. the timing for an action C</foo/bar> will be logged with the
+metric C<catalyst.stats.foo.bar.time>.
+
+The metric name is generated by L</statsd_metric_name_filter>.
+
 =head1 SEE ALSO
 
 =over
